==> string_translation_ui-8.x-1.0.tar.gz: string_translation_ui/src/Form/StringTranslationUiAddForm.php <==
<?php

namespace Drupal\string_translation_ui\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Serialization\Json;
use Drupal\locale\SourceString;
use Drupal\locale\StringDatabaseStorage;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure locale settings for this site.
 *
 * @internal
 */
class StringTranslationUiAddForm extends ConfigFormBase {

  /**
   * Context Name Default.
   */
  const CONTEXT_NAME_DEFAULT = 'stringTranslationUi';

  /**
   * String Database Storage.
   *
   * @var \Drupal\locale\StringDatabaseStorage
   */
  protected $stringDatabaseStorage;

  /**
   * Constructs a Form object.
   */
  public function __construct(StringDatabaseStorage $stringDatabaseStorage) {
    $this->stringDatabaseStorage = $stringDatabaseStorage;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('locale.storage')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'string_translation_ui_add_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['string_translation_ui.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('string_translation_ui.settings');

    $form['strings'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Strings to be added'),
      '#required' => TRUE,
      '#description' => $this->t('Use one string per line'),
    ];

    $contextDescription = $this->t('If you leave this field blank the context will be: <b>@contextNameDefault</b><br>', [
      '@contextNameDefault' => self::CONTEXT_NAME_DEFAULT,
    ]);

    if (!empty($config->get('contexts_used'))) {

      $contextDescription .= $this->t('Contexts that have been previously used:');

      $contextsUsed = Json::decode($config->get('contexts_used'));

      $contextDescription .= '<ul>';

      foreach ($contextsUsed as $context) {
        $contextDescription .= '<li>' . $context . '</li>';
      }

      $contextDescription .= '</ul>';
    }

    $form['context'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Context'),
      '#description' => $contextDescription,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

    parent::validateForm($form, $form_state);

    if (empty($form_state->getValue('strings'))) {
      $form_state->setErrorByName('strings', $this->t('You must enter strings.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $values = $form_state->getValues();

    $stringsToTranslate = explode(PHP_EOL, $values['strings']);

    $context = self::CONTEXT_NAME_DEFAULT;
    if (!empty($values['context'])) {
      $context = trim($values['context']);
    }

    foreach ($stringsToTranslate as $stringToTranslate) {

      $stringToTranslate = trim($stringToTranslate);

      $string = new SourceString();
      $string->setString($stringToTranslate);
      $string->context = $context;
      $string->setStorage($this->stringDatabaseStorage);
      $string->save();
    }

    $config = $this->config('string_translation_ui.settings');

    $contextsUsed = [];

    if (!empty($config->get('contexts_used'))) {
      $contextsUsed = Json::decode($config->get('contexts_used'));
    }

    if (array_search($context, $contextsUsed) === FALSE) {
      array_push($contextsUsed, $context);
    }

    $contextsUsed = Json::encode($contextsUsed);

    $config->set('contexts_used', $contextsUsed);

    $config->save();

    $this->messenger()->addMessage($this->t('Strings have been added'));
  }

}

==> string_translation_ui-8.x-1.1.tar.gz: string_translation_ui/src/Form/StringTranslationUiAddForm.php <==
<?php

namespace Drupal\string_translation_ui\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Serialization\Json;
use Drupal\locale\SourceString;
use Drupal\locale\StringDatabaseStorage;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;

/**
 * Configure locale settings for this site.
 *
 * @internal
 */
class StringTranslationUiAddForm extends ConfigFormBase {

  /**
   * Context Name Default.
   */
  const CONTEXT_NAME_DEFAULT = 'stringTranslationUi';

  /**
   * String Database Storage.
   *
   * @var \Drupal\locale\StringDatabaseStorage
   */
  protected $stringDatabaseStorage;

  /**
   * Module Handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * Constructs a Form object.
   */
  public function __construct(StringDatabaseStorage $stringDatabaseStorage, ModuleHandlerInterface $module_handler) {
    $this->stringDatabaseStorage = $stringDatabaseStorage;
    $this->moduleHandler = $module_handler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('locale.storage'),
      $container->get('module_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'string_translation_ui_add_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['string_translation_ui.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('string_translation_ui.settings');

    $form['strings'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Strings to be added'),
      '#required' => TRUE,
      '#description' => $this->t('Use one string per line'),
    ];

    $contextDescription = $this->t('Please use only lowercase letters, numbers, and underscores. If you leave this field blank the context will be: <b>@contextNameDefault</b><br>', [
      '@contextNameDefault' => self::CONTEXT_NAME_DEFAULT,
    ]);

    if (!empty($config->get('contexts_used'))) {

      $contextDescription .= $this->t('Contexts that have been previously used:');

      $contextsUsed = Json::decode($config->get('contexts_used'));

      sort($contextsUsed);

      $contextDescription .= '<ul>';

      foreach ($contextsUsed as $context) {
        $contextDescription .= '<li>' . $context . '</li>';
      }

      $contextDescription .= '</ul>';
    }

    $form['context'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Context'),
      '#description' => $contextDescription,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

    parent::validateForm($form, $form_state);

    if (empty($form_state->getValue('strings'))) {
      $form_state->setErrorByName('strings', $this->t('You must enter strings.'));
    }

    // Transform to lower case.
    $context = strtolower($form_state->getValue('context'));

    // Replace spaces to underline.
    $context = str_replace(' ', '_', $context);

    // Update value.
    $form_state->setValue('context', $context);

    // Validate special chars.
    if (!preg_match('/^[a-zA-Z0-9_]+$/', $context)) {
      $form_state->setErrorByName('context', $this->t('The context must contain only lowercase letters, numbers, and underscores.'));
    }

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $values = $form_state->getValues();

    $stringsToTranslate = explode(PHP_EOL, $values['strings']);

    $context = self::CONTEXT_NAME_DEFAULT;
    if (!empty($values['context'])) {
      $context = trim($values['context']);
    }

    foreach ($stringsToTranslate as $stringToTranslate) {

      $stringToTranslate = trim($stringToTranslate);

      $string = new SourceString();
      $string->setString($stringToTranslate);
      $string->context = $context;
      $string->setStorage($this->stringDatabaseStorage);
      $string->save();
    }

    $config = $this->config('string_translation_ui.settings');

    $contextsUsed = [];

    if (!empty($config->get('contexts_used'))) {
      $contextsUsed = Json::decode($config->get('contexts_used'));
    }

    if (array_search($context, $contextsUsed) === FALSE) {
      array_push($contextsUsed, $context);
      sort($contextsUsed);
    }

    $contextsUsed = Json::encode($contextsUsed);

    $config->set('contexts_used', $contextsUsed);

    $config->save();

    $this->messenger()->addMessage($this->t('Strings have been added'));

    if (!empty($this->moduleHandler->moduleExists('strings_i18n_json_export'))) {

      // We need to use ::service because this project is optional and for this
      // reason, we can't use dependency injection @codingStandardsIgnoreLine
      \Drupal::service('strings_i18n_json_export.json')->exportAllJsonFiles();
    }
  }

}
